# NOTE: rpmlint complains about "only non-binary in /usr/lib", but some of the
# files there, even though they are not ELF files, are in fact arch-specific.

Name:           sphinxtrain
Version:        1.0.8
Release:        9%{?dist}
Summary:        Acoustic model trainer for CMU's Sphinx tools

Group:          Applications/Multimedia
License:        BSD
URL:            http://cmusphinx.sourceforge.net/
Source0:        http://downloads.sourceforge.net/cmusphinx/%{name}-%{version}.tar.gz
# This file was accidentally omitted from the upstream source tarball.
Source1:        g2p_train.hpp
# Sent upstream 17 Jan 2013.  Specify the python extension so it is built and
# installed properly.
Patch0:         %{name}-extension.patch
# Sent upstream 6 Feb 2013.  Adapt to openfst 1.3.3.
Patch1:         %{name}-openfst.patch
# Sent upstream 28 Mar 2013.  Enable large file support.
Patch2:         %{name}-largefile.patch
# Big-endian fix
Patch3:         %{name}-1.0.8-bigendian.patch

BuildRequires:  Cython
BuildRequires:  lapack-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libsndfile-devel
BuildRequires:  opengrm-ngram-devel
BuildRequires:  libtool
BuildRequires:  perl
BuildRequires:  sphinxbase-devel
BuildRequires:  sphinxbase-python
BuildRequires:  python2-devel
BuildRequires:  python-setuptools
BuildRequires:  scipy

Requires:       perl(:MODULE_COMPAT_%{perl_version})
Requires:       openfst-tools
Requires:       sphinxbase

# Don't provide the script's perl interfaces, and thus don't require them
%global __provides_exclude perl
%global __requires_exclude SphinxTrain::Config
%global __requires_exclude %{__requires_exclude}|Queue::Job
%global __requires_exclude %{__requires_exclude}|SimpleConfig
%global __requires_exclude %{__requires_exclude}|Queue
%global __requires_exclude %{__requires_exclude}|SphinxTrain::Util

# Don't provide the python interface glue
%global __provides_exclude_from ^%{_libdir}/python.*\\.so$

%description
SphinxTrain is Carnegie Mellon University's open source acoustic model
trainer.  It contains the scripts and instructions necessary for building
models for the CMU Sphinx Recognizer.

%package -n python-%{name}
Summary:        Python interface to SphinxTrain
Group:          System Environment/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       sphinxbase-python%{?_isa}, scipy%{?_isa}

%description -n python-%{name}
Python interface to cmusphinx3.

%prep
%setup -q
%patch0
%patch1
%patch2
%patch3 -p1

# Add an accidentally omitted header file
cp -p %{SOURCE1} src/programs/g2p_train

# Remove spurious executable bits
find src -name \*.h -perm /0111 | xargs chmod a-x

# Find sphinxtrain files on 64-bit systems
function tweak()
{
  sed $1 $2 > $2.new
  touch -r $2 $2.new
  mv -f $2.new $2
}

if [ %{__isa_bits} = "64" ]; then
  tweak 's,lib/,lib64/,' scripts/sphinxtrain
  tweak "s,'lib','lib64'," scripts/000.comp_feat/make_feats.pl
  tweak "s,'lib','lib64'," scripts/000.comp_feat/slave_feat.pl
  tweak "s,'lib','lib64'," scripts/decode/psdecode.pl
  tweak "s,'lib','lib64'," scripts/decode/verify_dec.pl
  tweak "s,'lib','lib64'," scripts/decode/slave.pl
fi

# Help the dependency generator
for f in `grep -FRl /usr/bin/env python`; do
  cp -p $f $f.new
  sed -i 's|/usr/bin/env python|/usr/bin/python|' $f.new
  touch -r $f $f.new
  mv -f $f.new $f
done

# Regenerate files due to patch 2
autoreconf -fi

%build
# The configure script only turns PIC on for x86_64
%ifnarch x86_64
export CFLAGS="%{optflags} -fPIC -DPIC"
%endif

%configure --enable-g2p-decoder

# Get rid of undesirable hardcoded rpaths; also workaround libtool reordering
# -Wl,--as-needed after all the libraries.
sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|CC="g..|& -Wl,--as-needed|' \
    -i libtool
#"
make %{?_smp_mflags}

# Build the python interface
cd python
python2 setup.py build

%install
%make_install

# Get rid of stuff we don't want to install
rm -fr %{buildroot}%{_libdir}/%{name}/python %{buildroot}%{_includedir}

# Install the Python interface
mkdir -p %{buildroot}%{python_sitearch}
cd python
python2 setup.py install --skip-build --root %{buildroot}

# Fix permissions
for f in classlm2fst cluster_mixw dict_spd fstutils lat2dot lat2fsg \
    lat_rescore lat_rescore_fst lattice lattice_conv lattice_error \
    lattice_error_fst lattice_prune lda mllr mllt prune_mixw quantize_mixw \
    s3senmgau sendump test_arpalm test_corpus test_evaluation test_hmm \
    test_s3file test_s3dict test_s3model; do
  chmod 0755 %{buildroot}%{python_sitearch}/cmusphinx/$f.py
done
find %{buildroot}%{_libdir}/%{name}/scripts/lib -name \*.pm -o -name \*.txt | \
  xargs chmod 0644

%files
%doc COPYING NEWS README
%{_bindir}/%{name}
%{_libexecdir}/%{name}/
%{_libdir}/%{name}/
%exclude %{python_sitearch}/*

%files -n python-%{name}
%{python_sitearch}/SphinxTrain*.egg-info
%{python_sitearch}/cmusphinx/

%changelog
* Tue Feb  4 2014 Jerry James <loganjerry@gmail.com> - 1.0.8-9
- Add openfst-tools and sphinxbase Requires
- Add big endian fix from Dan Horák

* Mon Aug 19 2013 Jerry James <loganjerry@gmail.com> - 1.0.8-8
- Find library files on 64-bit systems (bz 997986)

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.8-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 1.0.8-6
- Perl 5.18 rebuild

* Fri Mar 29 2013 Jerry James <loganjerry@gmail.com> - 1.0.8-5
- Add -largefile patch for large file support

* Wed Feb  6 2013 Jerry James <loganjerry@gmail.com> - 1.0.8-4
- Rebuild for openfst 1.3.3

* Thu Jan 17 2013 Jerry James <loganjerry@gmail.com> - 1.0.8-3
- Don't Require the perl interface that we don't Provide
- Fix the python interface to build and install properly

* Thu Jan 17 2013 Jerry James <loganjerry@gmail.com> - 1.0.8-2
- Fix the name of the python subpackage
- Make sure the main package doesn't include the python interface

* Tue Jan  1 2013 Jerry James <loganjerry@gmail.com> - 1.0.8-1
- Initial RPM
